@@ -355,14 +355,15 @@ void ViewSliders::configurationUpdate()
 		MDWSlider* mdw = ::qobject_cast<MDWSlider*>(_mdws[i]);
 		if (mdw && mdw->isVisibleTo(this))
 		{
-			if (mdw->labelExtentHint() > labelExtent)
-				labelExtent = mdw->labelExtentHint();
+			labelExtent = qMax(labelExtent, mdw->labelExtentHint());
+			//kDebug() << "########## EXTENT for " << id() << " is " << labelExtent;
 			haveCaptureLEDs = haveCaptureLEDs || mdw->hasCaptureLED();
 			haveMuteButtons = haveMuteButtons || mdw->hasMuteButton();
 		}
 
-		if (haveCaptureLEDs && haveMuteButtons)
-			break; // We know all we want. Lets break.
+		// The following "break" cannot be done any longer, as we need to calculate the highest labelExtent from ALL mdw's
+		//		if (haveCaptureLEDs && haveMuteButtons)
+		//			break; // We know all we want. Lets break.
 	}
    //kDebug(67100) << "topPartExtent is " << topPartExtent;
    bool firstVisibleControlFound = false;
@@ -372,8 +373,8 @@ void ViewSliders::configurationUpdate()
       MDWSlider* mdwSlider = ::qobject_cast<MDWSlider*>(_mdws[i]);
       if ( mdw )
       {
-	 // This is a bit hacky. Using "simple" can be wrong on the very first start of KMix (but usually it is not!)
-	ProfControl* matchingControl = findMdw(mdw->mixDevice()->id(), QString("simple"));
+	 // guiLevel has been set earlier, by inspecting the controls
+	ProfControl* matchingControl = findMdw(mdw->mixDevice()->id(), guiLevel);
 	mdw->setVisible(matchingControl != 0);
 
 	if ( mdwSlider )
